Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Libexif Rust Bindings
The exif-sys crate provides declarations and linkage for the libexif C library. Following the
*-sys package conventions, the exif-sys crate does not define higher-level abstractions over the
native libexif library functions.
Dependencies
In order to use the exif-sys crate, you must have the libexif library installed where it can be
found by pkg-config.
Usage
Add exif-sys as a dependency in Cargo.toml:
[]
= "0.1"
Import the exif_sys crate and use the functions as they're defined in the native libexif
library. See the libexif API documention for more usage
information.
Finding Help
Since exif-sys is no more than a wrapper around the native libexif library, the best source for
help is the information already available for libexif:
License
Copyright © 2016 David Cuddeback
Distributed under the MIT License.
Note: By using this crate, your executable will link to the libexif C library, which is licensed
under the LGPL version 2.1.